==> bootstrap-filestyle-1.2.1.tgz: bootstrap-filestyle/README.md <==
# Installation
> `npm install --save @types/bootstrap-filestyle`

# Summary
This package contains type definitions for bootstrap-filestyle (https://github.com/markusslima/bootstrap-filestyle).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/bootstrap-filestyle.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/bootstrap-filestyle/index.d.ts)
````ts
// Type definitions for bootstrap-filestyle 1.2
// Project: https://github.com/markusslima/bootstrap-filestyle
// Definitions by: Mustafa Salaheldin <https://github.com/mustafasalahuldin>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.3

/// <reference types="jquery"/>

interface FilestyleOptions {
    buttonText?: string | undefined;
    iconName?: string | undefined;
    buttonName?: string | undefined;
    size?: string | undefined;
    input?: boolean | undefined;
    badge?: boolean | undefined;
    icon?: boolean | undefined;
    buttonBefore?: boolean | undefined;
    disabled?: boolean | undefined;
    placeholder?: string | undefined;
}

interface JQuery {
    filestyle(options?: FilestyleOptions): JQuery;

    filestyle(method: 'clear' | 'destroy' | 'htmlIcon' | 'htmlInput' | 'pushNameFiles'): JQuery;

    filestyle(method: 'disabled' | 'buttonBefore' | 'icon' | 'input', value: boolean): JQuery;

    filestyle(method: 'size' | 'placeholder' | 'buttonText' | 'buttonName' | 'iconName', value: string): JQuery;
}

````

### Additional Details
 * Last updated: Thu, 08 Jul 2021 00:35:31 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)
 * Global values: none

# Credits
These definitions were written by [Mustafa Salaheldin](https://github.com/mustafasalahuldin).

==> bootstrap-filestyle-1.2.2.tgz: bootstrap-filestyle/README.md <==
# Installation
> `npm install --save @types/bootstrap-filestyle`

# Summary
This package contains type definitions for bootstrap-filestyle (https://github.com/markusslima/bootstrap-filestyle).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/bootstrap-filestyle.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/bootstrap-filestyle/index.d.ts)
````ts
// Type definitions for bootstrap-filestyle 1.2
// Project: https://github.com/markusslima/bootstrap-filestyle
// Definitions by: Mustafa Salaheldin <https://github.com/mustafasalahuldin>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.3

/// <reference types="jquery"/>

interface FilestyleOptions {
    buttonText?: string | undefined;
    iconName?: string | undefined;
    buttonName?: string | undefined;
    size?: string | undefined;
    input?: boolean | undefined;
    badge?: boolean | undefined;
    icon?: boolean | undefined;
    buttonBefore?: boolean | undefined;
    disabled?: boolean | undefined;
    placeholder?: string | undefined;
}

interface JQuery {
    filestyle(options?: FilestyleOptions): JQuery;

    filestyle(method: "clear" | "destroy" | "htmlIcon" | "htmlInput" | "pushNameFiles"): JQuery;

    filestyle(method: "disabled" | "buttonBefore" | "icon" | "input", value: boolean): JQuery;

    filestyle(method: "size" | "placeholder" | "buttonText" | "buttonName" | "iconName", value: string): JQuery;
}

````

### Additional Details
 * Last updated: Fri, 15 Sep 2023 19:06:48 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)
 * Global values: none

# Credits
These definitions were written by [Mustafa Salaheldin](https://github.com/mustafasalahuldin).
